<?php

namespace Modules\Church\Http\Controllers;

use App\Abstracts\Http\Controller;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Facades\Excel;
use Modules\Church\Export\ChurchesExport;
use Modules\Church\Models\Church;
use Modules\Church\Models\ChurchHistory;
use Modules\Church\Models\ChurchView;
use Modules\Demarcations\Models\Demarcation;
use Modules\PaymentReception\Models\PaymentReception;

class Main extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        $churches = ChurchView::withTrashed()->collect();
        return $this->response('church::churches.index', compact('churches'));
    }

    public function export(Request $request)
    {
        return Excel::download(new ChurchesExport, 'churches-'.time().'.xlsx');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        return $this->response('church::churches.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param Request $request
     * @return Response
     */
    public function store(Request $request)
    {
        $churchAutoInc = setting('church.last_church_code_number');

        $churchPrefix = setting('church.church_code_prefix');

        $request->merge(['code' => $churchPrefix.str_pad($churchAutoInc,3,"0",STR_PAD_LEFT)]);

        $img_path = 'public/img/empty_pages/churches.png';

        if($request->hasFile('photo')){
			$image = $request->file('photo');
            $name = time()*floor(rand()*10).'.'.$image->extension();
            $image->move(public_path().'/churches/', $name);

            $img_path = 'public/churches/'.$name;
        }

        $request->merge(['photo' => $img_path]);
        $request->merge(['enabled' => 1]);

        if(!$request->has('email') || trim($request->email == "")){
            $request->merge(['email' => time().'@deliverancechurch.international']);
        }

        $church = new Church();
        $church->create($request->all());

        setting(['church.last_church_code_number' => $churchAutoInc+1])->save();

        flash('Church was added successfully!')->success();

        return redirect()->route('church.index');
    }

    /**
     * Show the specified resource.
     *
     * @param int $id
     * @return Response
     */
    public function show($id)
    {
        $tableRefix = DB::getTablePrefix();
        $church = Church::find($id);
        // return json_encode($church->subregion);
        $year = "all";
        if(request()->has('year')){
            $year = request()->year;
        }

        $subRegion = Demarcation::join('church_histories', 'church_histories.demarcation_id', 'demarcations.id')->whereNull('church_histories.deleted_at')
            ->where('church_histories.church_id', $id)->select('demarcations.id', 'demarcations.name', 'demarcations.type')->first();
        $region = Demarcation::join('demarcation_histories', 'demarcation_histories.parent_id', 'demarcations.id')->whereNull('demarcation_histories.deleted_at')
            ->where('demarcation_histories.demarcation_id', $subRegion->id ?? 0)->select('demarcations.id', 'demarcations.name', 'demarcations.type')->first();
    
        $subregions = Demarcation::subregion()->orderBy('name', 'asc')->get();

        $statements = PaymentReception::join('payment_reception_items as pri', 'pri.payment_reception_id', 'payment_receptions.id')
            ->selectRaw($tableRefix.'payment_receptions.id, month, year, SUM(amount) as amount, payer_name, '.$tableRefix.'payment_receptions.created_at')->where('church_id', $id);
        
        if($year != "all"){
            $statements = $statements->where('year', $year);
        }
        
        $statements = $statements->orderByRaw("STR_TO_DATE(CONCAT('01 ', month, ' ', year), '%d %M %Y')")->groupBy('month')->groupBy('year')->get();

        // return json_encode($church);

        return $this->response('church::churches.show', compact('church', 'subregions', 'subRegion', 'region', 'statements'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        $church = Church::find($id);
        return $this->response('church::churches.edit', compact('church'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(Request $request, $id)
    {
        $img_path = 'public/img/empty_pages/churches.png';

        if($request->hasFile('photo')){
			$image = $request->file('photo');
            $name = time()*floor(rand()*10).'.'.$image->extension();
            $image->move(public_path().'/churches/', $name);

            $img_path = 'public/churches/'.$name;
        }

        $request->merge(['photo' => $img_path]);

        // return json_encode($request->all());

        $church = Church::find($id);
        $church->update($request->all());

        flash('Church was updates successfully!')->success();

        return redirect()->route('church.show', $church->id);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return Response
     */

	public function destroy(Request $request, $id){
		ChurchHistory::where('church_id', $id)->delete();
		$church = Church::findOrFail($id);

		$church->delete();

		flash('Church deleted successfully!')->error();

		return redirect()->back();
	}

    public function fetch_demarcations($search){

    }

    public function stop_history(Request $request, $id){
        $h = ChurchHistory::find($id);

        if($request->has('delete') && $request->delete == 1){
			$h->forceDelete();
		}
		else{
			$h->delete();
		}

        flash('Church history changed!')->error();

		return redirect()->back();
    }
}
